/*

  The MIT License (MIT)

  Copyright (c) 2015 thewknd

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  SOFTWARE.

*/

#include "Wire.h"
#include "veml6040.h"

VEML6040 RGBWSensor;

void setup() {
  Serial.begin(9600);
  Wire.begin();

  for (uint8_t t = 1; t < 8; t ++) {
    tcaselect(t);
    if (!RGBWSensor.begin()) {
      Serial.println("ERROR: couldn't detect a sensor");
      while (1) {}
    }
    /*
         init RGBW sensor with:
          - 320ms integration time
          - auto mode
          - color sensor enable
    */

    RGBWSensor.setConfiguration(VEML6040_IT_320MS + VEML6040_AF_AUTO + VEML6040_SD_ENABLE);

    delay(1500);
    Serial.println("Vishay VEML6040 RGBW color sensor auto mode example");
    Serial.println("CCT: Correlated color temperature in \260K");
    Serial.println("AL: Ambient light in lux");
    delay(1500);
  }



}

void loop() {
  for (uint8_t t = 1; t < 8; t ++) {
    tcaselect(t);
    Serial.print("RED: ");
    Serial.print(RGBWSensor.getRed());
    Serial.print(" GREEN: ");
    Serial.print(RGBWSensor.getGreen());
    Serial.print(" BLUE: ");
    Serial.print(RGBWSensor.getBlue());
    Serial.print(" WHITE: ");
    Serial.print(RGBWSensor.getWhite());
    Serial.print(" CCT: ");
    Serial.print(RGBWSensor.getCCT());
    Serial.print(" AL: ");
    Serial.println(RGBWSensor.getAmbientLight());
    delay(400);
  }
  Serial.println("New Frame");

}

#define TCAADDR 0x70

void tcaselect(uint8_t i) {
  if (i > 7) return;

  Wire.beginTransmission(TCAADDR);
  Wire.write(1 << i);
  Wire.endTransmission();
}
